<?php


function linkify($name){
	return str_replace(' ', '_', $name);
}

/**
 * OPTIONAL GET of the given GET Key i.e. dont throw a error if not there
 *
 * @package      forms
 * @subpackage   get
 * @author       Pulkit Gupta
 * @param        string $name The key of the $_GET array i.e. the name of the input / textarea text 
 * @param        string $default The value to return if the $_GET[$name] is NOT SET
 * @return       string Returns the string if the GET is there otherwise the default value given.
 * @since     	 1.0
 */
function optGET($name, $default = ''){

global $error;

	//Check the GETED NAME was GETed
	if(isset($_GET[$name])){
	
		return inputsec(htmlizer(trim($_GET[$name])));
		
	}else{
		
		return $default;
	
	}

}

/**
 * Takes care of Slashes
 *
 * @package      string
 * @author       Pulkit Gupta
 * @param        string $string The string that will be processed
 * @return       string A string that is safe to use for Database Queries, etc
 * @since     	 1.0
 */
function inputsec($string){

	if(!get_magic_quotes_gpc()){
	
		$string = addslashes($string);
	
	}else{
	
		$string = stripslashes($string);
		$string = addslashes($string);
	
	}
	
	return $string;

}

/**
 * Converts Special characters to html entities
 *
 * @package      string
 * @author       Pulkit Gupta
 * @param        string $string The string containing special characters
 * @return       string A string containing special characters replaced by html entities of the format &#ASCIICODE;
 * @since     	 1.0
 */
function htmlizer($string){

global $globals;

	$string = htmlentities($string, ENT_QUOTES, $globals['charset']);
	
	preg_match_all('/(&amp;#(\d{1,7}|x[0-9a-fA-F]{1,6});)/', $string, $matches);//r_print($matches);
	
	foreach($matches[1] as $mk => $mv){		
		$tmp_m = entity_check($matches[2][$mk]);
		$string = str_replace($matches[1][$mk], $tmp_m, $string);
	}
	
	return $string;
	
}

/**
 * A function to display preformatted array. Basically adds the <pre> before and after the print_r() output.
 *
 * @package      arrays
 * @author       Pulkit Gupta
 * @param        array $array
 * @return       string Best for HTML dump of an array.
 * @since     	 1.0
 */
function r_print($array){

	echo '<pre>';
	print_r($array);
	echo '</pre>';

}

/**
 * A function to get themes in array. Basically returns json decoded themes.
 *
 * @package      arrays
 * @author       Aakash Gupta
 * @param        
 * @return       $array to get theme.
 * @since     	 1.0
 */
function get_themes(){

	global $spobs, $themes;
	
	$themes = file_get_contents(dirname(__FILE__).'/themes.json');
	$themes = json_decode($themes, true);
	
	return $themes;
}

/**
 * A function to get categories in array. Basically returns json decoded categories.
 *
 * @package      arrays
 * @author       Aakash Gupta
 * @param        
 * @return       $array to get categories.
 * @since     	 1.0
 */
function get_categories(){

	global $spobs, $categories;
	
	$categories = file_get_contents(dirname(__FILE__).'/categories.json');
	$categories = json_decode($categories, true);
	
	return $categories;
}

/**
 * A function to count total number of themes. 
 *
 * @package      arrays
 * @author       Aakash Gupta
 * @param        
 * @return       $integer.
 * @since     	 1.0
 */
function num_themes(){

	global $themes;
	
	// If get_themes() is not loaded yet
	if(empty($themes)){$themes = get_themes(); } 
	$num = 0;
	
	foreach($themes as $slug => $theme){
		if(empty($theme['approved'])) continue;
		$num++;
	}
	
	return $num;
}

/**
 * OPTIONAL GET of the given REQUEST Key i.e. dont throw a error if not there
 *
 * @package      forms
 * @subpackage   request
 * @author       Pulkit Gupta
 * @param        string $name The key of the $_REQUEST array i.e. the name of the input / textarea text 
 * @param        string $default The value to return if the $_REQUEST[$name] is NOT SET
 * @return       string Returns the string if the REQUEST is there otherwise the default value given.
 * @since     	 1.0
 */
function optREQ($name, $default = ''){

global $error;

	//Check the POSTED NAME was posted
	if(isset($_REQUEST[$name])){
	
		return inputsec(htmlizer(trim($_REQUEST[$name])));
		
	}else{
		
		return $default;
	
	}

}	

function header_sm(){
	echo '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
	<title>SitePad Themes</title>
	<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1" />
	<meta name="keywords" content="website-builder, themes, blog, content-builder, site builder, sitepad, auto sitepad website builder, web hosting, web-hosting, drag-and-drop, drag-n-drop, drag n drop, blogs, static website, html" />
	
	<link rel="stylesheet" type="text/css" href="style.css" />
	<link rel="stylesheet" type="text/css" href="css/bootstrap.min.css" />
	<link rel="stylesheet" type="text/css" href="css/font-awesome.css" />
	
	<script src="https://ajax.googleapis.com/ajax/libs/jquery/1.11.2/jquery.min.js"></script>
	<script src="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.5/js/bootstrap.min.js"></script>	
	
</head>

<body>
	
<div class="container-fluid" id="site-wrapper">
	<div class="row">
		<div class="header">
			<img src="images/sitepad_logo.png" style="margin-top:-5px;">
			<span>SitePad</span>
		</div>
	</div>
	<div class="row"  id="site-canvas">
	';
}	
	
function footer_sm(){
	echo '
	<div class="container-fluid" style="background-color:#333333; color:#fff;padding:20px;">
		<div class="col-lg-12 col-md-12 col-sm-12">
			<center>&nbsp; &copy; '.date('Y').' <a href="http://www.softaculous.com">Softaculous Ltd.</a> &nbsp;&nbsp;&nbsp;All trademarks and logos are the property of their respective owners!</center>
		</div>
		
	</div>';
}
?>